@@ -1,5 +1,5 @@
-## ------------------------------------------------------------------------------------------------|
-#     Copyright (C) 2017 - 2018  Reza Mohammadi                                                    |
+## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
+#     Copyright (C) 2017 - 2019  Reza Mohammadi                                                    |
 #                                                                                                  |
 #     This file is part of ssgraph package.                                                        |
 #                                                                                                  |
@@ -8,10 +8,11 @@
 #     Software Foundation; see <https://cran.r-project.org/web/licenses/GPL-3>.                    |
 #                                                                                                  |
 #     Maintainer: Reza Mohammadi <a.mohammadi@uva.nl>                                              |
-## ------------------------------------------------------------------------------------------------|
-# Random generation for the mixture of t-distribution 
-# with mean equal to mean and standard deviation equal to sd.
-## ------------------------------------------------------------------------------------------------|
+## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
+#   Random generation for the mixture of t-distribution 
+#   with mean equal to mean and standard deviation equal to sd.
+## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
+
 rmixt = function( n = 10, weight = 1, df = 1, mean = 0, sd = 1 ) 
 {
 	length_mean = length( mean )
@@ -20,11 +21,13 @@ rmixt = function( n = 10, weight = 1, df = 1, mean = 0, sd = 1 )
    
 	component = sample( length( weight ), n, replace = TRUE, prob = weight ) 
 	
-	return( mean[component] + sd[component] * rt( n, df = df[component] ) ) 
+	return( mean[ component ] + sd[ component ] * stats::rt( n, df = df[ component ] ) ) 
 }
     
-# Density, distribution function, for the mixture of t-distribution 
-# with mean equal to mean and standard deviation equal to sd.
+## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
+#   Density, distribution function, for the mixture of t-distribution 
+#   with mean equal to mean and standard deviation equal to sd.
+## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 dmixt = function( x, weight = 1, df = 1, mean = 0, sd = 1 ) 
 {
 	length_mean = length( mean )
@@ -33,8 +36,9 @@ dmixt = function( x, weight = 1, df = 1, mean = 0, sd = 1 )
 	
 	densmixt = 0
 	for( i in 1:length_mean )
-		densmixt = densmixt + weight[i] * dt( ( x - mean[i] ) / sd[i], df[i] )
+		densmixt = densmixt + weight[ i ] * stats::dt( ( x - mean[ i ] ) / sd[ i ], df[ i ] )
 	
 	return( densmixt ) 
 }
     
+## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
